@@ -117,6 +117,7 @@ class SoundStreamTrainer(nn.Module):
         num_train_steps,
         batch_size,
         data_max_length = None,
+        data_max_length_seconds = None,
         folder,
         lr = 2e-4,
         grad_accum_every = 4,
@@ -173,6 +174,11 @@ class SoundStreamTrainer(nn.Module):
 
         # create dataset
 
+        assert not (exists(data_max_length) and exists(data_max_length_seconds))
+
+        if exists(data_max_length_seconds):
+            data_max_length = data_max_length_seconds * soundstream.target_sample_hz
+
         self.ds = SoundDataset(
             folder,
             max_length = data_max_length,
@@ -264,6 +270,17 @@ class SoundStreamTrainer(nn.Module):
         assert path.exists()
         pkg = torch.load(str(path), map_location = 'cpu')
 
+        # if loading from old version, make a hacky guess
+
+        if len(pkg.keys()) > 20:
+            self.unwrapped_soundstream.load_state_dict(pkg)
+
+            if self.use_ema:
+                self.ema_soundstream.ema_model.load_state_dict(pkg)
+            return
+
+        # otherwise load things normally
+
         self.unwrapped_soundstream.load_state_dict(pkg['model'])
 
         if self.use_ema:
@@ -471,6 +488,7 @@ class SemanticTransformerTrainer(nn.Module):
         audio_conditioner: Optional[AudioConditionerBase] = None,
         dataset: Optional[Dataset] = None,
         data_max_length = None,
+        data_max_length_seconds = None,
         folder = None,
         lr = 3e-4,
         grad_accum_every = 1,
@@ -517,6 +535,11 @@ class SemanticTransformerTrainer(nn.Module):
         if not exists(self.ds):
             assert exists(folder), 'folder must be passed in, if not passing in a custom dataset for text conditioned audio synthesis training'
 
+            assert not (exists(data_max_length) and exists(data_max_length_seconds))
+
+            if exists(data_max_length_seconds):
+                data_max_length = data_max_length_seconds * wav2vec.target_sample_hz
+
             self.ds = SoundDataset(
                 folder,
                 max_length = data_max_length,
@@ -700,6 +723,7 @@ class CoarseTransformerTrainer(nn.Module):
         dataset: Optional[Dataset] = None,
         ds_fields: Tuple[str, ...] = ('raw_wave', 'raw_wave_for_soundstream', 'text'),
         data_max_length = None,
+        data_max_length_seconds = None,
         folder = None,
         lr = 3e-4,
         grad_accum_every = 1,
@@ -749,6 +773,11 @@ class CoarseTransformerTrainer(nn.Module):
         if not exists(self.ds):
             assert exists(folder), 'folder must be passed in, if not passing in a custom dataset for text conditioned audio synthesis training'
 
+            assert not (exists(data_max_length) and exists(data_max_length_seconds))
+
+            if exists(data_max_length_seconds):
+                data_max_length = tuple(data_max_length_seconds * hz for hz in (wav2vec.target_sample_hz, soundstream.target_sample_hz))
+
             self.ds = SoundDataset(
                 folder,
                 max_length = data_max_length,
@@ -936,6 +965,7 @@ class FineTransformerTrainer(nn.Module):
         audio_conditioner: Optional[AudioConditionerBase] = None,
         dataset: Optional[Dataset] = None,
         data_max_length = None,
+        data_max_length_seconds = None,
         dataset_normalize = False,
         folder = None,
         lr = 3e-4,
@@ -984,6 +1014,11 @@ class FineTransformerTrainer(nn.Module):
         if not exists(self.ds):
             assert exists(folder), 'folder must be passed in, if not passing in a custom dataset for text conditioned audio synthesis training'
 
+            assert not (exists(data_max_length) and exists(data_max_length_seconds))
+
+            if exists(data_max_length_seconds):
+                data_max_length = data_max_length_seconds * soundstream.target_sample_hz
+
             self.ds = SoundDataset(
                 folder,
                 max_length = data_max_length,
